==> adalid-alfa-2.1.0-sources.jar: adalid/core/properties/StringProperty.java <==
/*
 * Copyright 2017 Jorge Campins y David Uzcategui
 *
 * Este archivo forma parte de Adalid.
 *
 * Adalid es software libre; usted puede redistribuirlo y/o modificarlo bajo los terminos de la
 * licencia "GNU General Public License" publicada por la Fundacion "Free Software Foundation".
 * Adalid se distribuye con la esperanza de que pueda ser util, pero SIN NINGUNA GARANTIA; sin
 * siquiera las garantias implicitas de COMERCIALIZACION e IDONEIDAD PARA UN PROPOSITO PARTICULAR.
 *
 * Para mas detalles vea la licencia "GNU General Public License" en http://www.gnu.org/licenses
 */
package adalid.core.properties;

import adalid.core.annotations.BaseField;
import adalid.core.annotations.BusinessKey;
import adalid.core.annotations.CastingField;
import adalid.core.annotations.CharacterDataGen;
import adalid.core.annotations.CharacterKey;
import adalid.core.annotations.ColumnField;
import adalid.core.annotations.DescriptionProperty;
import adalid.core.annotations.DiscriminatorColumn;
import adalid.core.annotations.FileReference;
import adalid.core.annotations.NameProperty;
import adalid.core.annotations.PropertyAggregation;
import adalid.core.annotations.PropertyField;
import adalid.core.annotations.StringField;
import adalid.core.annotations.UniformResourceLocator;
import adalid.core.annotations.UniqueKey;
import adalid.core.annotations.UrlProperty;
import adalid.core.annotations.VariantString;
import adalid.core.data.types.StringData;
import adalid.core.interfaces.Property;
import java.lang.annotation.Annotation;
import java.util.List;

/**
 * @author Jorge Campins
 */
public class StringProperty extends StringData implements Property {

    @Override
    protected List<Class<? extends Annotation>> getValidFieldAnnotations() {
        List<Class<? extends Annotation>> valid = super.getValidFieldAnnotations();
        valid.add(BaseField.class);
        valid.add(BusinessKey.class);
        valid.add(CastingField.class);
        valid.add(CharacterKey.class);
        valid.add(CharacterDataGen.class);
        valid.add(ColumnField.class);
        valid.add(DescriptionProperty.class);
        valid.add(DiscriminatorColumn.class);
        valid.add(FileReference.class);
        valid.add(NameProperty.class);
        valid.add(PropertyField.class);
        valid.add(PropertyAggregation.class);
        valid.add(StringField.class);
        valid.add(UniqueKey.class);
        valid.add(UrlProperty.class);
        valid.add(UniformResourceLocator.class);
        valid.add(VariantString.class);
        return valid;
    }

}

==> adalid-alfa-5.2.0-sources.jar: adalid/core/properties/StringProperty.java <==
/*
 * Copyright 2017 Jorge Campins y David Uzcategui
 *
 * Este archivo forma parte de Adalid.
 *
 * Adalid es software libre; usted puede redistribuirlo y/o modificarlo bajo los terminos de la
 * licencia "GNU General Public License" publicada por la Fundacion "Free Software Foundation".
 * Adalid se distribuye con la esperanza de que pueda ser util, pero SIN NINGUNA GARANTIA; sin
 * siquiera las garantias implicitas de COMERCIALIZACION e IDONEIDAD PARA UN PROPOSITO PARTICULAR.
 *
 * Para mas detalles vea la licencia "GNU General Public License" en http://www.gnu.org/licenses
 */
package adalid.core.properties;

import adalid.core.annotations.*;
import adalid.core.data.types.*;
import adalid.core.interfaces.*;
import java.lang.annotation.Annotation;
import java.util.List;

/**
 * @author Jorge Campins
 */
public class StringProperty extends StringData implements AlphanumericProperty {

    @Override
    protected List<Class<? extends Annotation>> getValidFieldAnnotations() {
        List<Class<? extends Annotation>> valid = super.getValidFieldAnnotations();
        valid.add(BaseField.class);
        valid.add(BusinessKey.class);
        valid.add(CastingField.class);
        valid.add(CharacterDataGen.class);
        valid.add(ColumnField.class);
        valid.add(DescriptionProperty.class);
//      valid.add(DiscriminatorColumn.class); // 2020/05/03
        valid.add(EmbeddedDocument.class);
        valid.add(FileReference.class);
        valid.add(NameProperty.class);
        valid.add(PropertyField.class);
        valid.add(PropertyAggregation.class);
        valid.add(StringField.class);
        valid.add(UniqueKey.class);
        valid.add(UrlProperty.class);
        valid.add(UniformResourceLocator.class);
        valid.add(VariantString.class);
        return valid;
    }

}
